# BMAutomation

This is a test BenchmarkAutomation package. You can check it on [Github BMAutomation](https://github.com/YuudachiXMMY/BMAutomation).

## Dependency
This library utilizes these libraries `pyautogui`, `uiautomation`, `pywin32`.

## TestPyPI
Please check test packages on TestPyPI [here](https://test.pypi.org/project/BMAutomation/)

If you are interested in using a test package, install the test package using
```
pip install -i https://test.pypi.org/simple/ bmautomation
```